.. cooler documentation master file, created by
   sphinx-quickstart on Sun Jan 17 11:53:23 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Cooler
======

Cooler is a Python support library for .cool/.mcool files: an efficient storage format for high resolution genomic interaction matrices.

The cooler package aims to facilitate:

* Creation, aggregation and manipulation of genomically-labeled sparse matrices.
* Querying: sequential and range query patterns and tabular and sparse/dense array retrieval.
* Scalable out-of-core operations on the data.
* Data export and visualization.

Follow cooler development on `GitHub <https://github.com/open2c/cooler>`_.


Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   datamodel
   concepts
   schema
   api
   cli
   releasenotes


* :ref:`genindex`
* :ref:`Glossary`